<?php
/**
 * @package    Latham_Liners
 * @subpackage Latham_Liners/public
 * @author     Get Smart Group <plugins@thegetsmartgroup.com>
 */
 

class Latham_Liners_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	
	
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		

	}

			/**
			 * Register the stylesheets for the public-facing side of the site.
			 *
			 * @since    1.0.0
			 */
			public function enqueue_styles() {

				/**
				 * This function is provided for demonstration purposes only.
				 *
				 * An instance of this class should be passed to the run() function
				 * defined in Latham_Liners_Loader as all of the hooks are defined
				 * in that particular class.
				 *
				 * The Latham_Liners_Loader will then create the relationship
				 * between the defined hooks and the functions defined in this
				 * class.
				 */

				wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/public.min.css', array(), $this->version, 'all' );

			}

			/**
			 * Register the JavaScript for the public-facing side of the site.
			 *
			 * @since    1.0.0
			 */
			public function enqueue_scripts() {

					/**
					 * This function is provided for demonstration purposes only.
					 *
					 * An instance of this class should be passed to the run() function
					 * defined in Latham_Liners_Loader as all of the hooks are defined
					 * in that particular class.
					 *
					 * The Latham_Liners_Loader will then create the relationship
					 * between the defined hooks and the functions defined in this
					 * class.
					 */
					wp_enqueue_script('jquery');
					//wp_enqueue_script( $this->plugin_name . '-load-image', plugin_dir_url( __FILE__ ) . 'js/load-image.js',  true );
					//wp_enqueue_script( $this->plugin_name . '-easy-paginate', plugin_dir_url( __FILE__ ) . 'js/jquery.easyPaginate.js', array( 'jquery' ), $this->version, true ); 
					wp_register_script( $this->plugin_name . '-steps', plugin_dir_url( __FILE__ ) . 'js/jquery.smartWizard.js', array( 'jquery' ), $this->version, true ); 
					wp_register_script( $this->plugin_name . '-slick', plugin_dir_url( __FILE__ ) . 'js/slick.min.js', array( 'jquery' ), $this->version, true );
					wp_register_script( $this->plugin_name . '-izimodal', plugin_dir_url( __FILE__ ) . 'js/iziModal.min.js', array( 'jquery' ), $this->version, true );
					wp_register_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/latham-liners-public.min.js', array( 'jquery' ), $this->version, true );
					
					// Set Nonce Values so that the ajax calls are secure
					$latham_liners_nonce = wp_create_nonce( "latham_liners" );
					$plugin_options = get_option( 'latham-liners-admin' );
					if ( get_option( 'latham-liners-admin' ) && $plugin_options != FALSE) {
						$region = $plugin_options["gsg_ll_country"];
						$npt = $plugin_options["gsg_ll_checkbox_npt"];
					}

					$user_id = get_current_user_id();
					// pass ajax object to this javascript file
					// Add nonce values to this object so that we can access them in the plugin-name-admin.js javascript file
					wp_localize_script( $this->plugin_name, 'latham_liners_ajax_object', 
						array( 
							'ajax_url' => admin_url( 'admin-ajax.php' ),
							'latham_liners_nonce'=> $latham_liners_nonce,
							'npt' => $npt,
							'region' => $region
						) 
					);
					

			}    
			
			public function rs_get_thumbnails() {
				$plugin_options = get_option( 'latham-liners-admin' );
				if ( get_option( 'latham-liners-admin' ) && $plugin_options != FALSE) {
					$region = $plugin_options["gsg_ll_country"];
					$npt = $plugin_options["gsg_ll_checkbox_npt"];
				}
          
				$gcloud = new Latham_Liners_Gcloud($this->get_plugin_name(), $this->get_version() );

				$final_arr = $gcloud->auth_cloud_explicit('thumbs-2020');
				return $final_arr;
			}
			/**
			 * Enqueue scripts separately below to place in the header.
			 *
			 * @since    1.0.0
			 */
			public function enqueue_header_scripts() {
				wp_enqueue_script( $this->plugin_name . '-lozad', 'https://cdn.jsdelivr.net/npm/lozad/dist/lozad.min.js', $this->version,  false );
				wp_enqueue_script( $this->plugin_name . '-canvi', plugin_dir_url( __FILE__ ) . 'js/canvi.js', $this->version, true ); 
			}
			
			
			public function diplay_liner_configurator() {
					$public_display = plugin_dir_path( dirname( __FILE__ ) ) . 'public/partials/latham-liners-public-display.php';
					wp_enqueue_script( $this->plugin_name );
					wp_enqueue_script( $this->plugin_name . '-steps' );
					wp_enqueue_script( $this->plugin_name . '-slick' );
					wp_enqueue_script( $this->plugin_name . '-izimodal' );
					ob_start(); 
					require $public_display; 
					return ob_get_clean();
			}
			
			

			public function register_shortcodes() {
		    	add_shortcode( 'latham_liners', array( $this, 'diplay_liner_configurator') );
			}
			
			/**
		     * Retrieves a template part
		     *
		     * @since v1.5
		     *
		     * Taken from bbPress
		     *
		     * @param string $slug
		     * @param string $name Optional. Default null
		     *
		     * @uses  rcp_locate_template()
		     * @uses  load_template()
		     * @uses  get_template_part()
		     */
		    public static function liner_configurator_get_template($slug, $name = null, $load = true) {
		        // Execute code for this part
		        do_action('get_template_part_' . $slug, $slug, $name);

		        // Setup possible parts
		        $templates = array();
		        if (isset($name))
		            $templates[] = $slug . '-' . $name . '.php';
		        $templates[] = $slug . '.php';

		        // Allow template parts to be filtered
		        $templates = apply_filters('rcp_get_template_part', $templates, $slug, $name);

		        // Return the part that is found

		        return Latham_Liners_Public::liner_configurator_locate_template($templates, $load, false);
		    }
				
				
				
				/**
		     * Retrieve the name of the highest priority template file that exists.
		     *
		     * Searches in the STYLESHEETPATH before TEMPLATEPATH so that themes which
		     * inherit from a parent theme can just overload one file. If the template is
		     * not found in either of those, it looks in the theme-compat folder last.
		     *
		     * Taken from bbPress
		     *
		     * @since v1.5
		     *
		     * @param string|array $template_names Template file(s) to search for, in order.
		     * @param bool $load If true the template file will be loaded if it is found.
		     * @param bool $require_once Whether to require_once or require. Default true.
		     *                            Has no effect if $load is false.
		     * @return string The template filename if one is located.
		     */
		    public static function liner_configurator_locate_template($template_names, $load = false, $require_once = true) {
		        // No file found yet
		        $located = false;

		        // Try to find a template file
		        foreach ((array) $template_names as $template_name) {

		            // Continue if template is empty
		            if (empty($template_name))
		                continue;

		            // Trim off any slashes from the template name
		            $template_name = ltrim($template_name, '/');

		            // Check child theme first
		            if (file_exists(trailingslashit(get_stylesheet_directory()) . 'partials/' . $template_name)) {
		                $located = trailingslashit(get_stylesheet_directory()) . 'partials/' . $template_name;
		                break;

		                // Check parent theme next
		            } elseif (file_exists(trailingslashit(get_template_directory()) . 'partials/' . $template_name)) {
		                $located = trailingslashit(get_template_directory()) . 'partials/' . $template_name;
		                break;

		                // Check theme compatibility last
		            } elseif (file_exists(trailingslashit(Latham_Liners_Public::latham_liners_get_template_dir()) . $template_name)) {
		                $located = trailingslashit(Latham_Liners_Public::latham_liners_get_template_dir()) . $template_name;
		                break;
		            }
		        }

		        if (( true == $load ) && !empty($located))
		            load_template($located, $require_once);

		        return $located;
		    }



		    public static function latham_liners_get_template_dir() {
					
		        $path = plugin_dir_path( __FILE__ );
		        return $path.'/partials';
						
		    }

        /**
      	 * The name of the plugin used to uniquely identify it within the context of
      	 * WordPress and to define internationalization functionality.
      	 *
      	 * @since     1.0.0
      	 * @return    string    The name of the plugin.
      	 */
      	public function get_plugin_name() {
      		return $this->plugin_name;
      	}
      	/**
      	 * Retrieve the version number of the plugin.
      	 *
      	 * @since     1.0.0
      	 * @return    string    The version number of the plugin.
      	 */
      	public function get_version() {
      		return $this->version;
      	}
		        

		}